import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'hi_bugly_platform_interface.dart';

/// An implementation of [HiBuglyPlatform] that uses method channels.
class MethodChannelHiBugly extends HiBuglyPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('hi_bugly');

  @override
  Future<bool?> initialize({
    required String appID,
    bool debug = false,
  }) async {
    return await methodChannel.invokeMethod(
      'initialize',
      {
        'appID': appID,
        'debug': debug,
      },
    );
  }

  @override
  void postException({
    String name = '',
    String reason = '',
    String callStack = '',
    String extraInfo = '',
  }) {
    if (Platform.isAndroid) {
      final message = {
        'name': name,
        'reason': reason,
        'callStack': callStack,
        'extraInfo': extraInfo,
      };
      methodChannel.invokeMethod(
        'postException',
        {'message': message.toString()},
      );
    } else {
      methodChannel.invokeMethod('postException', {
        'name': name,
        'reason': reason,
        'callStack': callStack,
        'extraInfo': extraInfo,
      });
    }
  }
}
